==> scikit-criteria-0.5.dev0.tar.gz: scikit-criteria-0.5.dev0/README.md <==
# Scikit-Criteria

![image](https://github.com/quatrope/scikit-criteria/raw/master/res/logo_small.png)

**Multiple-criteria decision analysis**

<!-- BODY -->


[![Gihub Actions CI](https://github.com/quatrope/scikit-criteria/actions/workflows/CI.yml/badge.svg)](https://github.com/quatrope/scikit-criteria/actions/workflows/CI.yml)
[![Documentation Status](https://readthedocs.org/projects/scikit-criteria/badge/?version=latest&style=flat)](http://scikit-criteria.readthedocs.io)
[![License](https://img.shields.io/pypi/l/uttrs?color=blue)](https://www.tldrlegal.com/l/bsd3)
[![Python 3.7+](https://img.shields.io/badge/python-3.7+-blue.svg)](https://badge.fury.io/py/uttrs)


**Scikit-Criteria** is a collection of Multiple-criteria decision
analysis ([MCDA](https://en.wikipedia.org/wiki/Multiple-criteria_decision_analysis))
methods integrated into scientific python stack. Is Open source and commercially usable.

## Help & discussion mailing list

Our Google Groups mailing list is [here](https://groups.google.com/forum/#!forum/scikit-criteria).

**You can contact me at:** <jbcabral@gmail.com> (if you have a support
question, try the mailing list first)

## Code Repository & Issues

<https://github.com/quatrope/scikit-criteria>

## License

Scikit-Criteria is under
[The 3-Clause BSD License](https://raw.githubusercontent.com/quatrope/scikit-criteria/master/LICENSE.txt)

This license allows unlimited redistribution for any purpose as long as
its copyright notices and the license's disclaimers of warranty are
maintained.

## Citation

If you are using Scikit-Criteria in your research, please cite:

If you use scikit-criteria in a scientific publication, we would
appreciate citations to the following paper:

> Cabral, Juan B., Nadia Ayelen Luczywo, and José Luis Zanazzi 2016
> Scikit-Criteria: Colección de Métodos de Análisis Multi-Criterio
> Integrado Al Stack Científico de Python. In XLV Jornadas Argentinas de
> Informática E Investigación Operativa (45JAIIO)-XIV Simposio Argentino
> de Investigación Operativa (SIO) (Buenos Aires, 2016) Pp. 59-66.
> <http://45jaiio.sadio.org.ar/sites/default/files/Sio-23.pdf>.

Bibtex entry:


```bibtex
   @inproceedings{scikit-criteria,
        author={
            Juan B Cabral and Nadia Ayelen Luczywo and Jos\'{e} Luis Zanazzi},
        title={
            Scikit-Criteria: Colecci\'{o}n de m\'{e}todos de an\'{a}lisis
            multi-criterio integrado al stack cient\'{i}fico de {P}ython},
        booktitle = {
            XLV Jornadas Argentinas de Inform{\'a}tica
            e Investigaci{\'o}n Operativa (45JAIIO)-
            XIV Simposio Argentino de Investigaci\'{o}n Operativa (SIO)
            (Buenos Aires, 2016)},
        year={2016},
        pages = {59--66},
        url={http://45jaiio.sadio.org.ar/sites/default/files/Sio-23.pdf}
    }
```

**Full Publication:** http://sedici.unlp.edu.ar/handle/10915/58577

==> scikit-criteria-0.6.dev0.tar.gz: scikit-criteria-0.6.dev0/README.md <==
# Scikit-Criteria

![image](https://github.com/quatrope/scikit-criteria/raw/master/res/logo_wb.png)

**Multiple-criteria decision analysis**

<!-- BODY -->

[![QuatroPe](https://img.shields.io/badge/QuatroPe-Applications-1c5896)](https://quatrope.github.io/)
[![Gihub Actions CI](https://github.com/quatrope/scikit-criteria/actions/workflows/CI.yml/badge.svg)](https://github.com/quatrope/scikit-criteria/actions/workflows/CI.yml)
[![Documentation Status](https://readthedocs.org/projects/scikit-criteria/badge/?version=latest&style=flat)](http://scikit-criteria.readthedocs.io)
[![PyPI](https://img.shields.io/pypi/v/scikit-criteria)](https://pypi.org/project/scikit-criteria/)
[![Conda Forge](https://anaconda.org/conda-forge/scikit-criteria/badges/version.svg)](https://anaconda.org/conda-forge/scikit-criteria)
[![License](https://img.shields.io/pypi/l/uttrs?color=blue)](https://www.tldrlegal.com/l/bsd3)
[![Python 3.7+](https://img.shields.io/badge/python-3.7+-blue.svg)](https://badge.fury.io/py/uttrs)


**Scikit-Criteria** is a collection of Multiple-criteria decision
analysis ([MCDA](https://en.wikipedia.org/wiki/Multiple-criteria_decision_analysis))
methods integrated into scientific python stack. Is Open source and commercially usable.

## Help & discussion mailing list

Our Google Groups mailing list is [here](https://groups.google.com/forum/#!forum/scikit-criteria).

**You can contact me at:** <jbcabral@unc.edu.ar> (if you have a support
question, try the mailing list first)

## Code Repository & Issues

<https://github.com/quatrope/scikit-criteria>

## License

Scikit-Criteria is under
[The 3-Clause BSD License](https://raw.githubusercontent.com/quatrope/scikit-criteria/master/LICENSE.txt)

This license allows unlimited redistribution for any purpose as long as
its copyright notices and the license's disclaimers of warranty are
maintained.

## Citation

If you are using Scikit-Criteria in your research, please cite:

If you use scikit-criteria in a scientific publication, we would
appreciate citations to the following paper:

> Cabral, Juan B., Nadia Ayelen Luczywo, and José Luis Zanazzi 2016
> Scikit-Criteria: Colección de Métodos de Análisis Multi-Criterio
> Integrado Al Stack Científico de Python. In XLV Jornadas Argentinas de
> Informática E Investigación Operativa (45JAIIO)-XIV Simposio Argentino
> de Investigación Operativa (SIO) (Buenos Aires, 2016) Pp. 59-66.
> <http://45jaiio.sadio.org.ar/sites/default/files/Sio-23.pdf>.

Bibtex entry:


```bibtex
   @inproceedings{scikit-criteria,
        author={
            Juan B Cabral and Nadia Ayelen Luczywo and Jos\'{e} Luis Zanazzi},
        title={
            Scikit-Criteria: Colecci\'{o}n de m\'{e}todos de an\'{a}lisis
            multi-criterio integrado al stack cient\'{i}fico de {P}ython},
        booktitle = {
            XLV Jornadas Argentinas de Inform{\'a}tica
            e Investigaci{\'o}n Operativa (45JAIIO)-
            XIV Simposio Argentino de Investigaci\'{o}n Operativa (SIO)
            (Buenos Aires, 2016)},
        year={2016},
        pages = {59--66},
        url={http://45jaiio.sadio.org.ar/sites/default/files/Sio-23.pdf}
    }
```

**Full Publication:** http://sedici.unlp.edu.ar/handle/10915/58577
